@@ -1,6 +1,8 @@
-from .conc_coll import Concordance, Collocations, Counts
-from .corpus import Corpus, Corpus_from_identifiers, Corpus_from_identifiers as CorpusFromIdentifiers
-from .dispersion import Dispersion
-from .nbtokenizer import Tokens, tokenize
+"""Text analysis functionality, including building text corpora."""
 from .chunking import Chunks
+from .conc_coll import Concordance, Collocations, Counts
+from .corpus import Corpus, CorpusFromIdentifiers, \
+    CorpusFromIdentifiers as CorpusFromIdentifiers
+from .dispersion import Dispersion
 from .geo_data import GeoData
+from .nbtokenizer import Tokens, tokenize
