@@ -1,10 +1,9 @@
-import pandas as pd
 from pandas import DataFrame
 
-from ..api.dhlab_api import document_corpus, get_metadata
+from dhlab.api.dhlab_api import document_corpus, get_metadata
 
 
-class Corpus():
+class Corpus:
     def __init__(
             self,
             doctype=None,
@@ -42,7 +41,7 @@ class Corpus():
         return
 
 
-class Corpus_from_identifiers(Corpus):
+class CorpusFromIdentifiers(Corpus):
     def __init__(self, identifiers=None):
         self.corpus = get_metadata(urnlist(identifiers))
 
